#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class min_vol_frac_for_matrix_sol(Real):
    """
    Set Minimum Vol. Frac. for Matrix Solution.
    """

    fluent_name = "min-vol-frac-for-matrix-sol"

